#!/bin/bash -x
#
# Author: Jacob Martinson <martinson.jacob at gmail.com>
#
# REQUIRED VARS: DARCHOME binary host

PATH=/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin

DARCHOME=/home/misjxm/darc-0.1
host=localhost
binary=${DARCHOME}/bin/aide-0.10.linux

if [ ! -d "$DARCHOME" ]; then
  echo "DARCHOME dir does not exist: $DARCHOME "
  exit 1
fi

. ${DARCHOME}/config.sh

if [ -z $host ]; then
  echo "'host' variable not found in env."; exit 1
fi

if [ -z $binary ]; then
  echo "'binary' variable not found in env."; exit 1
fi

if [ ! -f $binary ]; then
  echo "File does not exist: $binary"; exit 1
fi

if [ -z $username ]; then
  echo "'username' variable not found in env."; exit 1
fi

if [ -z $sshport ]; then
  echo "'sshport' variable not found in env."; exit 1
fi

if [ -z $id_dsa ]; then
  echo "'id_dsa' variable not found in env."; exit 1
fi

if [ ! -f $id_dsa ]; then
  echo "File does not exist: $id_dsa"; exit 1
fi

config=${confdir}/baseconfig.${host}
if [ ! -f "$config" ]; then
  echo "Basconfig file does not exist: $config"
  exit 1
fi

umask 077

# dont initialize db if baseline already exists.
if [ -f "$baseline" ]; then
  echo "Refusing to overwrite existing baseline: $baseline"
  exit 1
fi

# GENERATE PATH NAME
path=/tmp/`passgen -l 8`
if [ $? -ne 0 ]; then
  echo "Unable to execute passgen command."
  exit 1
fi

# PUT BINARY ON TARGET
sftp $host <<EOF
! echo put $binary $path
put $binary $path
! echo chmod 700 $path
chmod 700 $path
EOF

# GENERATE A DB
sshcmd="ssh -v -t -i $id_dsa -p $sshport ${username}@${host} sudo nice -n 19 $path -i --config='-'"
echo $cmd >>$log

$sshcmd > $baseline 2>>$log <<EOF
database_out=stdout
`cat ${config}`
EOF

# REMOVE BINARY FROM TARGET
sftp -oIdentityFile=$id_dsa -oPort=$sshport ${username}@${host} <<EOF
! echo rm $path
rm $path
EOF

## TRIM AIDE STDERR THAT COMES OVER SSH
mv $baseline ${baseline}.tmp
cat ${baseline}.tmp | egrep -v '^$|AIDE, version|###' > $baseline
rm ${baseline}.tmp
